@@ -13,7 +13,7 @@ class SettingsDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit SettingsDialog(QWidget *parent = 0);
+    explicit SettingsDialog(QString &aAppletId, QWidget *parent = 0);
     ~SettingsDialog();
 
     void dumpSettings() const;
@@ -25,14 +25,17 @@ public slots:
 private slots:
     void showAbout();
     void showQtAbout();
+    void rotateToggle(bool);
 
 private:
     void loadSettings();
     void buildFontList();
-    void fillCbTZ();
+//    void fillCbTZ();
     int calcOffset() const;
+    void fillTZlist();
 
 private:
+    QString m_appletId;
     Ui::SettingsDialog *ui;
     QFont m_font;
 //    int m_defTZoffset;
